==> nextcloud-app-tasks-0.16.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ka_GE.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "აუცილებელი",
    "Today" : "დღეს",
    "Week" : "კვირა",
    "All" : "ყველა",
    "Current" : "ამჟამინდელი",
    "Completed" : "დასრულებული",
    "Tasks" : "დავალებები",
    "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
    "Hidden" : "უჩინარი",
    "Visible" : "ჩანს",
    "Automatic" : "ავტომატური",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "Can edit" : "შეუძლია შეცვალოს",
    "Edit" : "რედაქტირება",
    "Export" : "ექსპორტი",
    "Delete" : "წაშლა",
    "Unshare" : "გაზიარების შეწყვეტა",
    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
    "Name" : "სახელი",
    "Deleted" : "გაუქმდა",
    "Restore" : "აღდგენა",
    "Delete permanently" : "სამუდამოდ წაშლა",
    "Cancel" : "უარყოფა",
    "Close" : "დახურვა",
    "Select tags to filter by" : "ფილტრაციისთვის აირჩიეთ ტეგები",
    "Change sort order" : "განლაგების შეცვლა",
    "Start date" : "დაწყების თარიღი",
    "Due date" : "განპირობებულია თარიღისთვის",
    "Last modified" : "ბოლო ცვლილება",
    "Priority" : "პრიორიტეტი",
    "Alphabetically" : "ანბანის მიხედვით",
    "Manually" : "ხელით",
    "Task is completed" : "დავალება დასრულებულია",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n დასრულებული დავალება","%n დასრულებული დავალება"],
    "Tomorrow" : "ხვალ",
    "All day" : "მთელი დღე",
    "Details" : "დეტალები",
    "Select tags" : "აირჩიეთ ტეგები",
    "Notes" : "ჩანაწერები",
    "Reminders" : "შემახსენებლები",
    "Repeat" : "გამეორება",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
    "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
    "Set start date" : "საწყისი დრო",
    "Set due date" : "განპირობებულია თარიღისთვის"
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-app-tasks-0.17.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/tasks/l10n/ka_GE.js <==
OC.L10N.register(
    "tasks",
    {
    "Important" : "აუცილებელი",
    "Today" : "დღეს",
    "Week" : "კვირა",
    "All" : "ყველა",
    "Current" : "ამჟამინდელი",
    "Completed" : "დასრულებული",
    "Tasks" : "დავალებები",
    "Hidden" : "უჩინარი",
    "Visible" : "ჩანს",
    "Automatic" : "ავტომატური",
    "Visibility of Smart Collections" : "ჭკვიანი კოლექციების ხილვადობა",
    "Share with users or groups" : "გაზიარება მოხმარებლებთან ან ჯგუფებთან",
    "Can edit" : "შეუძლია შეცვალოს",
    "An empty name is not allowed." : "ცარიელი სახელი არაა ნებადართული",
    "Edit" : "რედაქტირება",
    "Export" : "ექსპორტი",
    "Delete" : "წაშლა",
    "Unshare" : "გაზიარების შეწყვეტა",
    "Name" : "სახელი",
    "Deleted" : "გაუქმდა",
    "Restore" : "აღდგენა",
    "Delete permanently" : "სამუდამოდ წაშლა",
    "Cancel" : "უარყოფა",
    "Go back" : "უკან დაბრუნება",
    "Close" : "დახურვა",
    "Select tags to filter by" : "ფილტრაციისთვის აირჩიეთ ტეგები",
    "Start date" : "დაწყების თარიღი",
    "Due date" : "განპირობებულია თარიღისთვის",
    "Last modified" : "ბოლო ცვლილება",
    "Priority" : "პრიორიტეტი",
    "Alphabetically" : "ანბანის მიხედვით",
    "Tags" : "ტეგები",
    "Manually" : "ხელით",
    "Change sort order" : "განლაგების შეცვლა",
    "Task is completed" : "დავალება დასრულებულია",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n დასრულებული დავალება","%n დასრულებული დავალება"],
    "Tomorrow" : "ხვალ",
    "When shared show full event" : "როდესაც გაზიარებულია გამოჩნდეს სრული მოვლენა",
    "When shared show only busy" : "როდესაც გაზიარებულია გამოჩნდეს მხოლოდ დაკავებული",
    "When shared hide this event" : "როდესაც გაზიარებულია არ გამოჩნდეს ეს მოვლენა",
    "Task not found!" : "დაველბა ვერ იქნა ნაპოვნი!",
    "Set start date" : "საწყისი დრო",
    "Set due date" : "განპირობებულია თარიღისთვის",
    "All day" : "მთელი დღე",
    "Details" : "დეტალები",
    "Select tags" : "აირჩიეთ ტეგები",
    "Notes" : "ჩანაწერები"
},
"nplurals=2; plural=(n!=1);");
